@@ -1,11 +1,12 @@
 import os
 import warnings
 
-from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython
+from pyaedt.application.Analysis import Analysis
+from pyaedt.generic.general_methods import is_ironpython
+from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.Model3DLayout import Modeler3DLayout
 from pyaedt.modules.Mesh3DLayout import Mesh3d
 from pyaedt.modules.SolveSetup import Setup3DLayout
-from pyaedt.application.Analysis import Analysis
 
 if is_ironpython:
     from pyaedt.modules.PostProcessor import PostProcessor
@@ -203,7 +204,7 @@ class FieldAnalysis3DLayout(Analysis):
                 k += 1
         return spar
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_mesh_stats(self, setup_name, variation_string="", mesh_path=None):
         """Export mesh statistics to a file.
 
@@ -231,7 +232,7 @@ class FieldAnalysis3DLayout(Analysis):
         self.odesign.ExportMeshStats(setup_name, variation_string, mesh_path)
         return mesh_path
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_all_return_loss_list(self, excitation_names=[], excitation_name_prefix=""):
         """Retrieve a list of all return losses for a list of excitations.
 
@@ -264,7 +265,7 @@ class FieldAnalysis3DLayout(Analysis):
             spar.append("S({},{})".format(i, i))
         return spar
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_all_insertion_loss_list(self, trlist=[], reclist=[], tx_prefix="", rx_prefix=""):
         """Retrieve a list of all insertion losses from two lists of excitations (driver and receiver).
 
@@ -303,7 +304,7 @@ class FieldAnalysis3DLayout(Analysis):
             spar.append("S({},{})".format(i, j))
         return spar
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_next_xtalk_list(self, trlist=[], tx_prefix=""):
         """Retrieve a list of all the near end XTalks from a list of excitations (driver and receiver).
 
@@ -335,7 +336,7 @@ class FieldAnalysis3DLayout(Analysis):
                 k += 1
         return next
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_fext_xtalk_list(self, trlist=[], reclist=[], tx_prefix="", rx_prefix="", skip_same_index_couples=True):
         """Retrieve a list of all the far end XTalks from two lists of exctitations (driver and receiver).
 
@@ -409,7 +410,7 @@ class FieldAnalysis3DLayout(Analysis):
         setups = list(self.oanalysis.GetSetups())
         return setups
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_setup(self, setupname="MySetupAuto", setuptype=None, props={}):
         """Create a setup.
 
@@ -445,7 +446,7 @@ class FieldAnalysis3DLayout(Analysis):
         self.setups.append(setup)
         return setup
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_setup(self, setupname, setuptype=None):
         """Retrieve a setup.
 
@@ -472,7 +473,7 @@ class FieldAnalysis3DLayout(Analysis):
         self.analysis_setup = setupname
         return setup
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete_setup(self, setupname):
         """Delete a setup.
 
