@@ -279,6 +279,9 @@ def decompose_variable_value(variable_value, full_variables={}):
             if loc:
                 loc_units = loc.span()[0]
                 extract_units = variable_value[loc_units:]
+                chars = set("+*/()[]")
+                if any((c in chars) for c in extract_units):
+                    return variable_value, units
                 try:
                     float_value = float(variable_value[0:loc_units])
                     units = extract_units
@@ -644,7 +647,7 @@ class VariableManager(object):
         var_dict = {}
         all_names = {}
         for obj in object_list:
-            if self._app._is_object_oriented_enabled():
+            if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
                 listvar = list(obj.GetChildObject("Variables").GetChildNames())
             else:
                 listvar = list(obj.GetVariables())
@@ -799,11 +802,15 @@ class VariableManager(object):
             raise Exception("Unhandled input type to the design property or project variable.")  # pragma: no cover
 
         # Get all design and project variables in lower case for a case-sensitive comparison
-        if self._app._is_object_oriented_enabled():
+        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
             var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
         else:
             var_list = list(desktop_object.GetVariables())  # pragma: no cover
         lower_case_vars = [var_name.lower() for var_name in var_list]
+        if self._app.design_type == "Maxwell Circuit" and "$" not in variable_name:
+            prop_server = "Instance:{}".format(desktop_object.GetName())
+        else:
+            prop_server = "{0}Variables".format(var_type)
 
         if variable_name.lower() not in lower_case_vars:
             try:
@@ -812,7 +819,7 @@ class VariableManager(object):
                         "NAME:AllTabs",
                         [
                             "NAME:{0}VariableTab".format(var_type),
-                            ["NAME:PropServers", "{0}Variables".format(var_type)],
+                            ["NAME:PropServers", prop_server],
                             [
                                 "NAME:NewProps",
                                 [
@@ -842,7 +849,7 @@ class VariableManager(object):
                             "NAME:AllTabs",
                             [
                                 "NAME:{}VariableTab".format(var_type),
-                                ["NAME:PropServers", "{}Variables".format(var_type)],
+                                ["NAME:PropServers", prop_server],
                                 [
                                     "NAME:ChangedProps",
                                     [
@@ -866,7 +873,7 @@ class VariableManager(object):
                     "NAME:AllTabs",
                     [
                         "NAME:{}VariableTab".format(var_type),
-                        ["NAME:PropServers", "{}Variables".format(var_type)],
+                        ["NAME:PropServers", prop_server],
                         [
                             "NAME:ChangedProps",
                             [
@@ -884,7 +891,7 @@ class VariableManager(object):
                     ],
                 ]
             )
-        if self._app._is_object_oriented_enabled():
+        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
             var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
         else:
             var_list = list(desktop_object.GetVariables())  # pragma: no cover
@@ -957,7 +964,7 @@ class VariableManager(object):
         """
         desktop_object = self.aedt_object(var_name)
         var_type = "Project" if desktop_object == self._oproject else "Local"
-        if self._app._is_object_oriented_enabled():
+        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
             var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
         else:
             var_list = list(desktop_object.GetVariables())  # pragma: no cover
@@ -1062,10 +1069,12 @@ class Variable(object):
                 scale = AEDT_UNITS[self.unit_system][self._units]
             except KeyError:
                 scale = 1
-        if isinstance(scale, tuple):
-            return scale[0](self._value, True)
+            if isinstance(scale, tuple):
+                return scale[0](self._value, True)
+            else:
+                return self._value / scale
         else:
-            return self._value / scale
+            return self._value
 
     @property
     def string_value(self):
