@@ -77,6 +77,21 @@ class Maxwell(object):
         design_file = os.path.join(self.working_directory, "design_data.json")
         return design_file
 
+    @pyaedt_function_handler()
+    def change_symmetry_multiplier(self, value=1):
+        """Set the Design Symmetry Multiplier to the selected value.
+
+        Parameters
+        ----------
+        value : int, optional
+            Value used as the Design Symmetry Multiplier coefficient. The default value is ``1``.
+
+        Returns
+        -------
+        bool
+        """
+        return self.change_design_settings({"Multiplier": value})
+
     @pyaedt_function_handler()
     def change_inductance_computation(self, compute_transient_inductance=True, incremental_matrix=False):
         """Enable the inductance computation for the transient analysis and set the incremental matrix.
@@ -100,16 +115,9 @@ class Maxwell(object):
 
         >>> oDesign.SetDesignSettings
         """
-        self.odesign.SetDesignSettings(
-            [
-                "NAME:Design Settings Data",
-                "ComputeTransientInductance:=",
-                compute_transient_inductance,
-                "ComputeIncrementalMatrix:=",
-                incremental_matrix,
-            ]
+        return self.change_design_settings(
+            {"ComputeTransientInductance": compute_transient_inductance, "ComputeIncrementalMatrix": incremental_matrix}
         )
-        return True
 
     @pyaedt_function_handler()
     def set_core_losses(self, objects, value=True):
@@ -1206,11 +1214,8 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
 
     @property
     def xy_plane(self):
-        """Maxwell 2D plane between `"XY"` and `"about Z"`."""
-        if self.design_solutions.xy_plane == "XY":
-            return True
-        else:
-            return False
+        """Maxwell 2D plane between `True` and `False`."""
+        return self.design_solutions.xy_plane
 
     @xy_plane.setter
     @pyaedt_function_handler()
@@ -1235,14 +1240,7 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
     @model_depth.setter
     def model_depth(self, value):
         """Set model depth."""
-
-        self.odesign.SetDesignSettings(
-            [
-                "NAME:Design Settings Data",
-                "ModelDepth:=",
-                value,
-            ]
-        )
+        return self.chaange_design_settings({"ModelDepth": value})
 
     @pyaedt_function_handler()
     def generate_design_data(self, linefilter=None, objectfilter=None):
@@ -1444,3 +1442,53 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             else:
                 return bound, False
         return False, False
+
+    @pyaedt_function_handler()
+    def assign_end_connection(self, objects, resistance=0, inductance=0, bound_name=None):
+        """Assign End connection to a list of objects.
+
+        Parameters
+        ----------
+        objects : list of int or str or :class:`pyaedt.modeler.Object3d.Object3d`
+            List of objects to apply end connection.
+        resistance : float or str, optional
+            Resistance value. If float is provided then it is assumed in Ohm.
+            The default value is "0ohm".
+        inductance : float or str, optional
+            Inductance value. If float is provided then it is assumed in Henry.
+            The default value is "0H".
+        bound_name : str, optional
+            Name of the End connection boundary.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`
+            New created object.
+
+        References
+        ----------
+
+        >>> oModule.AssignEndConnection
+        """
+        if self.solution_type not in ["EddyCurrent", "Transient"]:
+            self.logger.error("Excitation applicable only to Eddy current or Transient Solver.")
+            return False
+        if len(objects) < 2:
+            self.logger.error("At least 2 objects are needed.")
+            return False
+        objects = self.modeler.convert_to_selections(objects, True)
+        if not bound_name:
+            bound_name = generate_unique_name("EndConnection")
+
+        props = OrderedDict(
+            {
+                "Objects": objects,
+                "ResistanceValue": self.modeler._arg_with_dim(resistance, "ohm"),
+                "InductanceValue": self.modeler._arg_with_dim(inductance, "H"),
+            }
+        )
+        bound = BoundaryObject(self, bound_name, props, "EndConnection")
+        if bound.create():
+            self.boundaries.append(bound)
+            return bound
+        return False
