@@ -1,6 +1,6 @@
 import os
 
-from pyaedt import aedt_exception_handler
+from pyaedt import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
 
 
@@ -127,7 +127,7 @@ class Part(object):
                 self._compdef[key] = [str(i) if not i is str else i for i in cs]
         return self._compdef[key]
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def zero_offset(self, kw):  # Returns True if cs at kw is at [0, 0, 0]
         """Check if the coordinate system defined by kw is [0, 0, 0].
 
@@ -320,7 +320,7 @@ class Part(object):
         """
         return self._multiparts.name + "_" + self._name
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_relative_cs(self, app):
         """Create a parametric coordinate system.
 
@@ -359,7 +359,7 @@ class Part(object):
         """
         return self.name + "_rot_cs"
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def do_rotate(self, app, aedt_object):
         """Set the rotation coordinate system relative to the parent coordinate system.
 
@@ -396,7 +396,7 @@ class Part(object):
 
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def insert(self, app):
         """Insert 3D component in AEDT.
 
@@ -475,7 +475,7 @@ class Antenna(Part, object):
             p["Polarization"] = self._compdef["polarization"]
         return p
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _insert(self, app, target_cs=None, units=None):
         if not target_cs:
             target_cs = self._multiparts.cs_name
@@ -499,7 +499,7 @@ class Antenna(Part, object):
             )
         return a
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def insert(self, app, units=None):
         """Insert antenna in HFSS SBR+.
 
