@@ -767,7 +767,7 @@ class GlobalService(rpyc.Service):
         # (to finalize the service, if needed)
         pass
 
-    def exposed_start_service(self, hostname, beta_options=None):
+    def exposed_start_service(self, hostname, beta_options=None, use_aedt_relative_path=False):
         """Starts a new Pyaedt Service and start listen.
 
         Returns
@@ -802,14 +802,19 @@ class GlobalService(rpyc.Service):
                         lines = f1.readlines()
                         for line in lines:
                             f.write(line)
+                if not use_aedt_relative_path:
+                    aedt_exe = os.path.join(ansysem_path, executable)
+                else:
+                    aedt_exe = executable
                 if non_graphical:
                     ng_feature = "-features=SF6694_NON_GRAPHICAL_COMMAND_EXECUTION,SF159726_SCRIPTOBJECT"
                     if beta_options:
                         for option in range(beta_options.__len__()):
                             if beta_options[option] not in ng_feature:
                                 ng_feature += "," + beta_options[option]
+
                     command = [
-                        os.path.join(ansysem_path, executable),
+                        aedt_exe,
                         ng_feature,
                         "-ng",
                         "-RunScriptAndExit",
@@ -821,7 +826,7 @@ class GlobalService(rpyc.Service):
                         for option in range(beta_options.__len__()):
                             if beta_options[option] not in ng_feature:
                                 ng_feature += "," + beta_options[option]
-                    command = [os.path.join(ansysem_path, executable), ng_feature, "-RunScriptAndExit", dest_file]
+                    command = [aedt_exe, ng_feature, "-RunScriptAndExit", dest_file]
                 print(command)
                 subprocess.Popen(command)
                 return port
